using System;
using com.workman.cm3d2.scene.dailyEtc;
using Schedule;
using UnityEngine;

public class Debug_mgr : MonoBehaviour
{
	private void Start()
	{
		GameObject f_goParent = GameObject.Find("/UI Root");
		this.mgr = UTY.GetChildObject(f_goParent, "Manager", false).GetComponent<SceneMgr>();
	}

	public void OpenDaytimePanel()
	{
		ScheduleAPI.DayStartManage();
		int[] facilityPowerUpMaterialIDArray = FacilityDataTable.GetFacilityPowerUpMaterialIDArray();
		foreach (int materialID in facilityPowerUpMaterialIDArray)
		{
			GameMain.Instance.FacilityMgr.SetHavePowerUpMaterial(materialID, true);
		}
		this.mgr.GetManager<DailyMgr>().OpenDaytimePanel();
	}

	public void OpenNightPanel()
	{
		this.mgr.GetManager<DailyMgr>().OpenNightPanel();
	}

	public void CloseDailyPanel()
	{
		this.mgr.GetManager<DailyMgr>().CloseDailyPanel();
	}

	public void OpenResultDaytimePanel()
	{
		this.mgr.GetManager<ResultWorkMgr>().OpenResultDaytimePanel();
	}

	public void OpenResultNightPanel()
	{
		this.mgr.GetManager<ResultWorkMgr>().OpenResultNightPanel();
	}

	public void OpenResultIncomePanel()
	{
		this.mgr.GetManager<ResultIncomeMgr>().OpenResultIncomePanel();
	}

	public void OpenStatusPanel()
	{
	}

	public void OpenUserEditPanel()
	{
		this.mgr.GetManager<UserEditMgr>().OpenUserEditPanel();
	}

	public void OpenStartDailyPanel()
	{
		this.mgr.GetManager<StartDailyMgr>().OpenStartDailyPanel();
	}

	public void OpenMaidExaminationPanel()
	{
		this.mgr.GetManager<MaidExaminationMgr>().OpenMaidExaminationPanel(null, null, null);
	}

	public void CloseMaidExaminationPanel()
	{
		this.mgr.GetManager<MaidExaminationMgr>().CloseMaidExaminationPanel();
	}

	public void OpenStaffRollPanel()
	{
		this.mgr.GetManager<StaffRollMgr>().OpenStaffRollPanel();
	}

	public void OpenStatusPanelForChuBLip()
	{
	}

	public void UpdateStatusPanelForChuBLip()
	{
	}

	public void OpenProfilePanelForChuBLip()
	{
	}

	public void CloseProfilePanelForChuBLip()
	{
	}

	private const string uiRootPath = "/UI Root";

	private SceneMgr mgr;
}
